/*
 * Copyright (c) 2008-2010 Nokia Corporation and/or its subsidiary(-ies). All rights reserved.
 *    
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *    
 *  * Redistributions of source code must retain the above copyright notice, this
 *    list of conditions and the following disclaimer.
 *  * Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *  * Neither the name of Nokia Corporation nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *    
 *    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 *    AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 *    IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 *    DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 *    FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 *    DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 *    SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 *    CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 *    OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 *    OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *    
 *    Description:  
 */

#ifndef CONTACTSMODELDOCUMENT_H
#define CONTACTSMODELDOCUMENT_H

// INCLUDES
#include <akndoc.h>

#include <cntdb.h>

// CONSTANTS

// FORWARD DECLARATIONS
class  CEikAppUi;

// CLASS DECLARATION

/**
*  CContactsModelDocument application class.
*/
class CContactsModelDocument : public CAknDocument
    {
    public: // Constructors and destructor
        /**
        * Two-phased constructor.
        */
        static CContactsModelDocument* NewL(CEikApplication& aApp);

        /**
        * Destructor.
        */
        virtual ~CContactsModelDocument();

    public: // New functions
		/**
		* GetItemL
		*
		*   Returns text representation of the specified contact item.
		*
		* Parameters
		*	anIndex - contact item index
		*
		* Returns
		*	String with the text description of the contact item
		**/
		HBufC * GetItemL(TInt anIndex);

		/**
		* ItemCount
		*
		*   Return the number of contact items in the default database
		*
		* Returns
		*	Number of contact items
		**/
		TInt ItemCount();

		/**
		* UpdateContactsL
		*
		*   Retrives the list of contact item ids from the default database.
		**/
		void UpdateContactsL();

		/**
		* ImportL
		*
		*   Reads from the stream vCard and tries
		*   to import them in the default database.
		*
		* Parameters
		*	aReadStream - read stream with vCards
		*
		* Returns
		*	KErrNone or KErrGeneral if import failed
		**/
		TInt ImportL(RReadStream& aReadStream);

		/**
		* ExportL
		*
		*   Exports the selected item from the default contact database
		*	to the specified ouput stream as vCard.
		*
		* Parameters
		*	aWriteStream - output stream to write the item as vCard
		*   aExportItem - the index of item for export
		*
		* Returns
		*	Nothing
		**/
		void ExportL(RWriteStream& aWriteStream, TInt aExportItem);


    private:

        /**
        * EPOC default constructor.
        */
        CContactsModelDocument(CEikApplication& aApp);
        void ConstructL();

    private:

        /**
        * From CEikDocument, create CContactsModelAppUi "App UI" object.
        */
        CEikAppUi* CreateAppUiL();

		// array of contact's ids that are displayed in the application
		CContactIdArray* iContacts;

		//text definition used to display contact items
		CContactTextDef* iTextDef;
    };

#endif

// End of File

