/*
 * Copyright (c) 2008-2010 Nokia Corporation and/or its subsidiary(-ies). All rights reserved.
 *    
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *    
 *  * Redistributions of source code must retain the above copyright notice, this
 *    list of conditions and the following disclaimer.
 *  * Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *  * Neither the name of Nokia Corporation nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *    
 *    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 *    AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 *    IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 *    DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 *    FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 *    DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 *    SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 *    CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 *    OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 *    OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *    
 *    Description:  
 */

// INCLUDE FILES
#include "ContactsModelDocument.h"
#include "ContactsModelContainer.h"

const TInt KGranularityOfArray = 10;

const TInt KBufferSize = 256;
// ================= MEMBER FUNCTIONS =======================

// ---------------------------------------------------------
// CContactsModelContainer::ConstructL(const TRect& aRect)
// EPOC two phased constructor
// ---------------------------------------------------------
//
void CContactsModelContainer::ConstructL(const TRect& aRect, CContactsModelDocument* aDocument)
    {
	iDocument = aDocument;
    CreateWindowL();
    SetRect(aRect);

	// create listbox control
    iListBox = new (ELeave) CAknSingleStyleListBox;
    iListBox->ConstructL(this, 0);
	iListBox->SetContainerWindowL(*this);
    iListBox->SetRect(aRect.Size());

	iListBoxRows = new (ELeave) CDesCArrayFlat( KGranularityOfArray );
	iListBox->Model()->SetItemTextArray( iListBoxRows );
	iListBox->Model()->SetOwnershipType(ELbmDoesNotOwnItemArray);

    iListBox->ActivateL();
    iListBox->CreateScrollBarFrameL(ETrue);
    iListBox->ScrollBarFrame()->SetScrollBarVisibilityL(CEikScrollBarFrame::EOn,
    	CEikScrollBarFrame::EAuto);

    ActivateL();
	MakeVisible(ETrue);
    }

// Destructor
CContactsModelContainer::~CContactsModelContainer()
    {
	delete iListBox;
	iListBox = NULL;

	if( iListBoxRows )
		{
		iListBoxRows->Reset();
		}
	delete iListBoxRows;
	iListBoxRows= NULL;
    }

// ---------------------------------------------------------
// CContactsModelContainer::SizeChanged()
// Called by framework when the view size is changed
// ---------------------------------------------------------
//
void CContactsModelContainer::SizeChanged()
    {
    }

// ---------------------------------------------------------
// CContactsModelContainer::CountComponentControls() const
// ---------------------------------------------------------
//
TInt CContactsModelContainer::CountComponentControls() const
    {
    return 1; // return nbr of controls inside this container
    }

// ---------------------------------------------------------
// CContactsModelContainer::ComponentControl(TInt aIndex) const
// ---------------------------------------------------------
//
CCoeControl* CContactsModelContainer::ComponentControl(TInt aIndex) const
    {
	if( aIndex > 0 )
		{
		return NULL;
		}
    return iListBox;
    }

// ---------------------------------------------------------
// CContactsModelContainer::Draw(const TRect& aRect) const
// ---------------------------------------------------------
//
void CContactsModelContainer::Draw(const TRect& /*aRect*/) const
    {
    CWindowGc& gc = SystemGc();
    TRect rect = Rect();
    gc.Clear(rect);
    }

// ---------------------------------------------------------
// CContactsModelContainer::HandleControlEventL(
//     CCoeControl* aControl,TCoeEvent aEventType)
// ---------------------------------------------------------
//
void CContactsModelContainer::HandleControlEventL(
    CCoeControl* /*aControl*/,TCoeEvent /*aEventType*/)
    {
    // TODO: Add your control event handler code here
    }

void CContactsModelContainer::UpdateL()
    {
	iListBoxRows->Reset();
	if( iDocument->ItemCount() > 0 )
		{
		//add items to the list box
		for( TInt i = 0; i < iDocument->ItemCount(); ++i )
			{

			HBufC* row = iDocument->GetItemL(i);
			CleanupStack::PushL(row);

			TBuf<KBufferSize> buf;
			buf.Format(_L("\t%S"), row);
			iListBoxRows->AppendL(buf);

			CleanupStack::PopAndDestroy();
			}
		//update the control
		iListBox->HandleItemAdditionL();
		}
	}

// return contacts items number
TInt CContactsModelContainer::ItemCount()
{
	return iDocument->ItemCount();
}

TKeyResponse CContactsModelContainer::OfferKeyEventL(const TKeyEvent& aKeyEvent, TEventCode aType)
    {
    return iListBox->OfferKeyEventL(aKeyEvent, aType);
    }

TInt CContactsModelContainer::GetSelectedItem()
	{
	return iListBox->CurrentItemIndex();
	}

// End of File
